@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     drivers/taylor.c
- Revision: $Id: taylor.c 91 2010-02-24 07:56:58Z awalther $
+ Revision: $Id: taylor.c 270 2011-08-24 09:51:54Z kulshres $
  Contents: Easy to use drivers for the evaluation of higher order derivative
            tensors and inverse/impicit function differentiation
  
@@ -12,10 +12,10 @@
  recipient's acceptance of the terms of the accompanying license file.
  
 ----------------------------------------------------------------------------*/
-#include <drivers/taylor.h>
-#include <interfaces.h>
-#include <adalloc.h>
-#include <taping_p.h>
+#include <adolc/drivers/taylor.h>
+#include <adolc/interfaces.h>
+#include <adolc/adalloc.h>
+#include "taping_p.h"
 
 #include <math.h>
 
@@ -396,7 +396,7 @@ void GauszSolve( double** J, int n, int* RI, int* CI, double* b ) {
 
 
 /****************************************************************************/
-int jac_solv( unsigned short tag, int n, double* x, double* b, unsigned short mode ) {
+int jac_solv( unsigned short tag, int n, const double* x, double* b, unsigned short mode ) {
     double *y;
     int i, newX = 0;
     int rc = 3;
@@ -642,7 +642,7 @@ int inverse_tensor_eval( short tag, int n, int d, int p,
     for(i=0;i<n;i++)
         for(j=0;j<dimten;j++)
             tensor[i][j] = 0;
-    MINDEC(rc,zos_forward(1,n,n,0,x,y));
+    MINDEC(rc,zos_forward(tag,n,n,0,x,y));
     if (d > 0) {
         if ((d != dold) || (p != pold)) {
             if (pold) { /* olvo 980728 */
@@ -743,7 +743,7 @@ int tensor_eval( short tag, int m, int n, int d, int p,
         for (j=0; j<dimten; j++)
             tensor[i][j] = 0;
     if (d == 0) {
-        MINDEC(rc,zos_forward(1,m,n,0,x,y));
+        MINDEC(rc,zos_forward(tag,m,n,0,x,y));
     } else {
         if ((d != dold) || (p != pold)) {
             if (pold) {
