@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     fo_rev.c
- Revision: $Id: fo_rev.c 116 2010-07-20 12:29:32Z awalther $
+ Revision: $Id: fo_rev.c 290 2012-01-16 11:45:01Z kulshres $
  Contents: Contains the routines :
            fos_reverse (first-order-scalar reverse mode)  : define _FOS_
            fov_reverse (first-order-vector reverse mode)  : define _FOV_
@@ -335,7 +335,7 @@ int int_reverse_safe(
 # define ADOLC_EXT_FCT_Z edfct->dpp_Z
 # define ADOLC_EXT_FCT_POINTER fov_reverse
 # define ADOLC_EXT_FCT_COMPLETE \
-  fov_reverse(m, edfct->dpp_U, n, edfct->dpp_Z)
+    fov_reverse(m, p, edfct->dpp_U, n, edfct->dpp_Z)
 # define ADOLC_EXT_FCT_SAVE_NUMDIRS ADOLC_CURRENT_TAPE_INFOS.numDirs_rev = nrows
 #endif
 #if !defined(_INT_REV_)
@@ -457,7 +457,7 @@ int int_reverse_safe(
 
     if (taycheck < 0) {
         fprintf(DIAG_OUT,"\n ADOL-C error: reverse fails because it was not"
-                " preceeded\nby a forward sweep with degree>0, keep=1!\n");
+                " preceded\nby a forward sweep with degree>0, keep=1!\n");
         exit(-2);
     };
 
@@ -469,9 +469,9 @@ int int_reverse_safe(
 
     /****************************************************************************/
     /*                                                            REVERSE SWEEP */
-
     operation=get_op_r();
     while (operation != start_of_tape) { /* Switch statement to execute the operations in Reverse */
+
         switch (operation) {
 
 
@@ -737,8 +737,8 @@ int int_reverse_safe(
 #else
                 { aTmp = ARES;
                   /* olvo 980713 nn: ARES = 0.0; */
-                  ARES_INC =  aTmp * TARG;
-                  AARG_INC += aTmp * TRES;
+                  ARES_INC =  (aTmp==0)?0:(aTmp * TARG);
+                  AARG_INC += (aTmp==0)?0:(aTmp * TRES);
                 }
 #endif      
 		break;
@@ -892,8 +892,8 @@ int int_reverse_safe(
                   AARG1_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG2_INC += aTmp * TARG1;
-                  AARG1_INC += aTmp * TARG2;
+                  AARG2_INC += (aTmp==0)?0:(aTmp * TARG1);
+                  AARG1_INC += (aTmp==0)?0:(aTmp * TARG2);
 #endif
             }
                 break;
@@ -975,7 +975,7 @@ int int_reverse_safe(
 		  AARG_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG_INC += coval * aTmp;
+                  AARG_INC += (aTmp==0)?0:(coval * aTmp);
 #endif
             }
 
@@ -1011,8 +1011,8 @@ int int_reverse_safe(
                   AARG2_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG1_INC += aTmp * r0;
-                  AARG2_INC += aTmp * r_0;
+                  AARG1_INC += (aTmp==0)?0:(aTmp * r0);
+                  AARG2_INC += (aTmp==0)?0:(aTmp * r_0);
 #endif
             }
 
@@ -1045,7 +1045,7 @@ int int_reverse_safe(
                   AARG_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG_INC += aTmp * r0;
+                  AARG_INC += (aTmp==0)?0:(aTmp * r0);
 #endif
                 }
 
@@ -1125,7 +1125,7 @@ int int_reverse_safe(
                   AARG_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG_INC += aTmp * TRES;
+                  AARG_INC += (aTmp==0)?0:(aTmp*TRES);
 #endif
             }
 
@@ -1150,7 +1150,7 @@ int int_reverse_safe(
                   AARG1_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG1_INC += aTmp * TARG2;
+                  AARG1_INC += (aTmp==0)?0:(aTmp * TARG2);
 #endif
             }
 
@@ -1177,7 +1177,7 @@ int int_reverse_safe(
                   AARG1_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG1_INC -= aTmp * TARG2;
+                  AARG1_INC -= (aTmp==0)?0:(aTmp * TARG2);
 #endif
             }
 
@@ -1214,7 +1214,7 @@ int int_reverse_safe(
                   AARG1_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG1_INC += aTmp * TARG2;
+                  AARG1_INC += (aTmp==0)?0:(aTmp * TARG2);
 #endif
                 }
                 break;
@@ -1242,7 +1242,7 @@ int int_reverse_safe(
                   AARG_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG_INC += aTmp * r0;
+                  AARG_INC += (aTmp==0)?0:(aTmp * r0);
 #endif
             }
                 break;
@@ -1276,7 +1276,7 @@ int int_reverse_safe(
                     AARG_INC |= aTmp;
 #else
                     ARES_INC = 0.0;
-                    AARG_INC += aTmp * r0;
+                    AARG_INC += (aTmp==0)?0:(aTmp * r0);
 #endif
             }
 
@@ -1307,7 +1307,7 @@ int int_reverse_safe(
                     AARG_INC |= aTmp;
 #else
                     ARES_INC = 0.0;
-                    AARG_INC += aTmp * r0;
+                    AARG_INC += (aTmp==0)?0:(aTmp * r0);
 #endif
                 }
 
@@ -1336,7 +1336,7 @@ int int_reverse_safe(
                   AARG1_INC |= aTmp;
 #else
                   ARES_INC = 0.0;
-                  AARG1_INC += aTmp * TARG2;
+                  AARG1_INC += (aTmp==0)?0:(aTmp * TARG2);
 #endif
             }
 
