@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     fortutils.h
- Revision: $Id: fortutils.h 42 2009-07-15 18:37:17Z awalther $
+ Revision: $Id: fortutils.h 106 2010-06-29 17:19:50Z kulshres $
  Contents: Internal tools to handle Fortran arrays
  
  Copyright (c) Andrea Walther, Andreas Griewank, Andreas Kowarz, 
@@ -16,7 +16,7 @@
 #if !defined(ADOLC_FORTUTILS_H)
 #define ADOLC_FORTUTILS_H 1
 
-#include <common.h>
+#include <adolc/common.h>
 
 /****************************************************************************/
 /*                                                         Now the C THINGS */
