@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     interfaces.h
- Revision: $Id: interfaces.h 62 2009-12-07 17:49:24Z awalther $
+ Revision: $Id: interfaces.h 272 2011-10-10 14:57:53Z kulshres $
  Contents: Declaration of the standard interfaces to ADOL-C forward and
            reverse calls (C++, C and Fortran callable C functions).
  
@@ -46,11 +46,11 @@
 #if !defined(ADOLC_INTERFACES_H)
 #define ADOLC_INTERFACES_H 1
 
-#include <common.h>
+#include <adolc/common.h>
 
 #if defined(SPARSE)
-#include <sparse/sparsedrivers.h>
-#include <sparse/sparse_fo_rev.h>
+#include <adolc/sparse/sparsedrivers.h>
+#include <adolc/sparse/sparse_fo_rev.h>
 #endif
 
 /****************************************************************************/
@@ -199,7 +199,7 @@ ADOLC_DLL_EXPORT int zos_forward_partx(short,int,int,int*,double**,double*);
 /* fos_forward(tag, m, n, keep, x[n], X[n], y[m], Y[m])                     */
 /* (defined in uni5_for.mc)                                                 */
 ADOLC_DLL_EXPORT int fos_forward(
-    short,int,int,int,double*,double*,double*,double*);
+    short,int,int,int,const double*,double*,double*,double*);
 
 /* fos_forward_nk(tag,m,n,x[n],X[n],y[m],Y[m])                              */
 /* (no keep, defined in uni5_for.c, but not supported in ADOL-C 1.8)        */
