@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     sparse/sparsedrivers.h
- Revision: $Id: sparsedrivers.h 157 2010-09-02 12:14:24Z kulshres $
+ Revision: $Id: sparsedrivers.h 176 2010-10-11 14:53:04Z awalther $
  Contents: This file containts some "Easy To Use" interfaces of sparse package.
  
  Copyright (c) Andrea Walther
@@ -59,7 +59,7 @@ ADOLC_DLL_EXPORT int sparse_jac
 /*     crs[i][ crs[i][0] = non-zero entries per row ]                       */
 /*                                                                          */
 
-ADOLC_DLL_EXPORT int hess_pat(short,int,double*,unsigned int**, int);
+ADOLC_DLL_EXPORT int hess_pat(short,int,const double*,unsigned int**, int);
 
 /*--------------------------------------------------------------------------*/
 /*                                          seed matrix for sparse hessian  */
@@ -74,14 +74,19 @@ ADOLC_DLL_EXPORT void generate_seed_hess
 /*                 options[2]);                                             */
 
 ADOLC_DLL_EXPORT int sparse_hess
-(short, int , int, double*, int *,
+(short, int , int, const double*, int *,
  unsigned int **, unsigned int **, double **,int*);
 
-void set_HP(
+ADOLC_DLL_EXPORT void set_HP(
     short          tag,        /* tape identification                     */
     int            indep,      /* number of independent variables         */
     unsigned int ** HP);
 
+ADOLC_DLL_EXPORT void get_HP(
+    short          tag,        /* tape identification                     */
+    int            indep,      /* number of independent variables         */
+    unsigned int *** HP);
+
 /*--------------------------------------------------------------------------*/
 /*                                                   JACOBIAN BLOCK PATTERN */
 
